@@ -22,4 +22,8 @@ class ConfigAlgo(Config):
         default=20,
         help_string="min watermark for disk utilization",
     )
+    disregard = ParamCreator.create_list_str(
+        default="/",
+        help_string="what mount points to disregard",
+    )
 
